@@ -1,12 +1,15 @@
 <?php
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # Module: Custom Global Settings
-# Author: Rolf Tjassens, Jos
-#-------------------------------------------------------------------------
-# CMS - CMS Made Simple is (c) 2011 by Ted Kulp (wishy@cmsmadesimple.org)
-# This project's homepage is: http://www.cmsmadesimple.org
+# Author: Rolf Tjassens (cmscanbesimple.org), Jos
+#---------------------------------------------------------------------------
+# CMS Made Simple - Power for the professional, Simplicity for the end user.
+# (c) 2004 - 2011 by Ted Kulp (wishy@cmsmadesimple.org)
+# (c) 2011 - 2018 by The CMS Made Simple Development Team
+# (c) 2018 and beyond by The CMS Made Simple Foundation
+# This project's homepage is: https://www.cmsmadesimple.org
 # The module's homepage is: http://dev.cmsmadesimple.org/projects/customgs
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -20,9 +23,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
-if (!isset($gCms)) exit;
+if ( !cmsms() ) exit;
 
 if (!$this->VisibleToAdminUser())
 {
@@ -74,8 +77,8 @@ echo $this->StartTabContent();
 	$daynames = implode("','",$days);
 	$daynamesmin = implode("','",$daysmin);
 
-	$DP_locale = "
-		$.datepicker.regional[''] = {
+	$datapicker_locale = "
+		$.datepicker.regional[''] = { 
 			closeText: '" . lang('close') . "',
 			prevText: '" . lang('previous') . "',
 			nextText: '" . lang('next') . "',
@@ -88,10 +91,10 @@ echo $this->StartTabContent();
 			isRTL: false,
 			showMonthAfterYear: false,
 			yearSuffix: ''
-		};
+		} ;
 		$.datepicker.setDefaults($.datepicker.regional['']);
 
-		$.timepicker.regional[''] = {
+		$.timepicker.regional[''] = { 
 			timeOnlyTitle: '" . $this->Lang('choosetime') . "',
 			timeText: '" . $this->Lang('time') . "',
 			hourText: '" . lang('hour') . "',
@@ -99,12 +102,13 @@ echo $this->StartTabContent();
 			currentText: '" . $this->Lang('now') . "',
 			closeText: '" . lang('close') . "',
 			ampm: false
-		};
+		} ;
 		$.timepicker.setDefaults($.timepicker.regional['']);
 	";
 
-	$smarty->assign('DP_locale', $DP_locale);
-	
+	$smarty->assign('cgs_url_path', $this->GetModuleURLPath());
+	$smarty->assign('datapicker_locale', $datapicker_locale);
+
 	echo $this->ProcessTemplate('admin_generaljs.tpl');
 	
 	foreach( $tabs as $tab )
@@ -131,4 +135,7 @@ echo $this->StartTabContent();
 
 echo $this->EndTabContent();
 
+#
+# EOF
+#
 ?>
\ No newline at end of file
