@@ -1,12 +1,15 @@
 <?php
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # Module: Custom Global Settings
-# Author: Rolf Tjassens, Jos
-#-------------------------------------------------------------------------
-# CMS - CMS Made Simple is (c) 2011 by Ted Kulp (wishy@cmsmadesimple.org)
-# This project's homepage is: http://www.cmsmadesimple.org
+# Author: Rolf Tjassens (cmscanbesimple.org), Jos
+#---------------------------------------------------------------------------
+# CMS Made Simple - Power for the professional, Simplicity for the end user.
+# (c) 2004 - 2011 by Ted Kulp (wishy@cmsmadesimple.org)
+# (c) 2011 - 2018 by The CMS Made Simple Development Team
+# (c) 2018 and beyond by The CMS Made Simple Foundation
+# This project's homepage is: https://www.cmsmadesimple.org
 # The module's homepage is: http://dev.cmsmadesimple.org/projects/customgs
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -20,9 +23,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
-if (!isset($gCms)) exit;
+if ( !cmsms() ) exit;
 
 if( !$this->CheckPermission('Custom Global Settings - Manage') )
 {
@@ -36,6 +39,122 @@ if ( isset($params['cancel']) )
 	$this->Redirect($id, 'defaultadmin', '', $params);
 }
 
+if ( isset($params['fieldselect']) )
+{
+	// multi actions
+	$fld_array = is_array($params['fieldselect']) ? array_keys($params['fieldselect']) : explode(',', $params['fieldselect']);
+	foreach ($fld_array as $key => $fieldid)
+	{
+		if( !is_numeric($fieldid) )
+		{
+			$params = array('module_error' => lang('missingparams'), 'active_tab' => 'fielddefs');
+			$this->Redirect($id, 'defaultadmin', '', $params);
+			return;
+		}
+	}
+  
+	switch ($params['multiaction'])
+	{
+		case 'movetotop':
+			// update the sortorder to make room on top
+			$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder + ?";
+			$result = $db->Execute($query, array(count($fld_array)));
+
+			// update the sortorder for the selected items
+			foreach ($fld_array as $key => $fieldid)
+			{
+				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = ? WHERE fieldid = ?";
+				$result = $db->Execute($query, array($key + 1, $fieldid));
+			}
+
+			break;
+
+		case 'movetobottom':
+			// find maximum value for sortorder
+			$query = "SELECT MAX(sortorder) AS maxsortorder FROM ".cms_db_prefix()."module_customgs";
+			$result = $db->Execute($query);
+
+			if( $result )
+			{
+				$fieldmax = $result->FetchRow();
+        
+				// update the sortorder for the selected items
+				foreach ($fld_array as $key => $fieldid)
+				{
+					$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = ? WHERE fieldid = ?";
+					$result = $db->Execute($query, array($fieldmax['maxsortorder'] + $key + 1, $fieldid));
+				}
+			}
+      
+			break;
+
+		case 'move':
+			// find the sortorder of the fieldsetstart field
+			$fieldgroup = $this->GetField($params['fieldgroup']);
+
+			// update the sortorder to make room on top within the fieldgroup
+			$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder + ? WHERE sortorder > ?";
+			$result = $db->Execute($query, array(count($fld_array), $fieldgroup['sortorder']));
+
+			// update the sortorder for the selected items
+			foreach ($fld_array as $key => $fieldid)
+			{
+				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = ? WHERE fieldid = ?";
+				$result = $db->Execute($query, array($fieldgroup['sortorder'] + $key + 1, $fieldid));
+			}
+
+			break;
+
+		case 'delete':
+			foreach ($fld_array as $fieldid)
+			{
+				$params['fieldid'] = $fieldid;
+
+				$field = $this->GetField($params['fieldid']);
+				if( $field === FALSE )
+				{
+					continue;
+				}
+
+				$query = "DELETE FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
+				$db->Execute($query, array($params['fieldid']));
+
+				// Put mention into the admin log
+				audit($params['fieldid'], 'Custom Global Settings - Fielddefinition', 'Deleted: ' . $field['name']);
+
+				// update the sortorder
+				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder - 1 WHERE sortorder > ?";
+				$result = $db->Execute($query, array($field['sortorder']));
+
+				// delete all tab-assignments
+				$query = "DELETE FROM " . cms_db_prefix() . "module_customgs_tabfield WHERE fieldid = ?";
+				$result = $db->Execute($query, array($params['fieldid']));
+
+				// delete fieldsetend
+				if ( $field['type'] == 'fieldsetstart' )
+				{
+					$field2 = $this->GetField( $field['name'] . '.' );
+
+					if( $field2 !== FALSE )
+					{
+						$query = "DELETE FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
+						$db->Execute($query, array($field2['fieldid']));
+
+						$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder - 1 WHERE sortorder > ?";
+						$result = $db->Execute($query, array($field2['sortorder']));
+				  }
+				}
+			}
+
+			break;
+	}
+
+	$params = array('tab_message'=> 'fielddefsupdated', 'active_tab' => 'fielddefs');
+	$this->Redirect($id, 'defaultadmin', '', $params);
+	return;
+
+}
+
 if( !isset($params['mode']) )
 {
 	$params = array('module_error' => lang('missingparams'), 'active_tab' => 'fielddefs');
@@ -53,7 +172,7 @@ switch ($params['mode'])
 			// check if name is empty
 			if ( empty($params['name']) ) $params['name'] = $params['type'] . "1";
 			// check if name already exists
-			While ( $this->GetField($params['name']) !== FALSE )
+			while ( $this->GetField($params['name']) !== FALSE )
 			{
 				if ( is_numeric(substr($params['name'], -1)) )
 				{
@@ -103,7 +222,7 @@ switch ($params['mode'])
 				// add also fieldsetend if fieldsetstart was added
 				if ( $params['type'] == 'fieldsetstart' )
 				{
-					$result = $db->Execute($query, array($params['name'], '', 'fieldsetend', '', $params['clearcache'], $field['maxsortorder'] + 2, $editors));
+					$result = $db->Execute($query, array($params['name'] . '.', '', 'fieldsetend', '', $params['clearcache'], $field['maxsortorder'] + 2, $editors));
 					$fieldid2 = $db->Insert_ID();
 				}
 
@@ -148,13 +267,16 @@ switch ($params['mode'])
 		}
 		
 		$field = $this->GetField($params['fieldid']);
+		
 		if( $field === FALSE )
 		{
 			$params = array('module_error'=> 'updatefailed', 'active_tab' => 'fielddefs');
 			$this->Redirect($id, 'defaultadmin', '', $params);
 		}
+
 		$query = "DELETE FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
 		$db->Execute($query, array($params['fieldid']));
+
 		// Put mention into the admin log
 		audit($params['fieldid'], 'Custom Global Settings - Fielddefinition', 'Deleted: ' . $field['name']);
 
@@ -162,14 +284,20 @@ switch ($params['mode'])
 		$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder - 1 WHERE sortorder > ?";
 		$result = $db->Execute($query, array($field['sortorder']));
 		
+    	// delete all tab-assignments
+    	$query = "DELETE FROM " . cms_db_prefix() . "module_customgs_tabfield WHERE fieldid = ?";
+    	$result = $db->Execute($query, array($params['fieldid']));
+
 		// delete fieldsetend
 		if ( $field['type'] == 'fieldsetstart' )
 		{
-			$field2 = $this->GetField($field['name']);
+			$field2 = $this->GetField( $field['name'] . '.' );
+			
 			if( $field2 !== FALSE )
 			{
 				$query = "DELETE FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
 				$db->Execute($query, array($field2['fieldid']));
+
 				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder - 1 WHERE sortorder > ?";
 				$result = $db->Execute($query, array($field2['sortorder']));
 			}
@@ -237,10 +365,10 @@ switch ($params['mode'])
 			// save fieldsetend
 			if ( $field['type'] == 'fieldsetstart' )
 			{
-				$fieldend = $this->GetField($field['name']);
+				$fieldend = $this->GetField($field['name'] . '.');
 				$result = $db->Execute($query, array($fieldend['fieldid']));
 				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET name = ?, editors = ? WHERE fieldid = ?";
-				$result = $db->Execute($query, array($params['name'], $editors, $fieldend['fieldid']));
+				$result = $db->Execute($query, array($params['name'] . '.', $editors, $fieldend['fieldid']));
 			}
 			
 			// save tab-assignments
@@ -258,7 +386,6 @@ switch ($params['mode'])
 						}
 					}
 				}
-				
 			}
 			
 
@@ -406,7 +533,8 @@ $smarty->assign('prompt_parsesmarty', $this->Lang('parsesmarty'));
 $smarty->assign('parsesmarty', $this->CreateInputCheckbox($id, 'parsesmarty', '1', $field['type'] == 'textarea' || $field['type'] == 'wysiwyg' ? $field['properties'] : ''));
 
 $smarty->assign('prompt_help', lang('help'));
-$smarty->assign('help', $this->CreateInputText($id, 'help', $field['help'], 80 ));
+//$smarty->assign('help', $this->CreateInputText($id, 'help', $field['help'], 80 ));
+$smarty->assign('help', $this->CreateTextArea(FALSE, $id, $field['help'], 'help', '', '', '', '', '', 3));
 
 $smarty->assign('prompt_clearcache', $this->Lang('clearstylesheetcache'));
 $smarty->assign('help_clearcache', $this->Lang('clearstylesheetcache_help'));
@@ -438,9 +566,9 @@ $smarty->assign('tabs', $tabslist);
 $smarty->assign('submit', $this->CreateInputSubmit($id, 'submitbutton', lang('submit')));
 $smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
 
-$smarty->assign('formstart', $this->CreateFormStart($id, 'editfielddef', $returnid));
-$smarty->assign('formend', $this->CreateFormEnd());
-
 echo $this->ProcessTemplate('editfielddef.tpl');
 
+#
+# EOF
+#
 ?>
\ No newline at end of file
