@@ -38,11 +38,15 @@ $lang['maxlength'] = 'Maximum Length';
 $lang['properties'] = 'Properties';
 $lang['properties_help1'] = 'Enter the choice values, each one on a new line. Also supports Value|OptionName pairs and/or Smarty tags';
 $lang['parsesmarty'] = 'Parse data by Smarty';
-$lang['clearstylesheetcache'] = 'Clear stylesheet cache';
-$lang['clearstylesheetcache_help'] = 'Automatically clear stylesheet cache after changing this setting. USE WITH CAUTION!';
+$lang['clearstylesheetcache'] = 'Renew stylesheet cache';
+$lang['clearstylesheetcache_help'] = 'Automatically renew stylesheet cache after changing this setting. USE WITH CAUTION!';
 $lang['showontab'] = 'Show on tab';
 $lang['fielddefadded'] = 'Field Definition is added';
 $lang['fielddefsupdated'] = 'Field Definition list is updated';
+$lang['withselected'] = 'With selected';
+$lang['movetotop'] = 'Move to top';
+$lang['movetobottom'] = 'Move to bottom';
+$lang['movetogroup'] = 'Move to group';
 
 
 /**
@@ -62,6 +66,9 @@ $lang['help_custom_modulename'] = 'You can change the Modulename here as you wis
 $lang['title_admin_section'] = 'Admin Section';
 $lang['help_admin_section'] = 'Choose the Admin Section (or top-level Admin Menu) this module belongs to. <b>Note</b>: Users with Editor permissions don\'t have access to the Site Admin section!';
 
+$lang['xml_export'] = 'Export settings to XML';
+$lang['xml_import'] = 'Import settings from XML';
+
 
 /**
  * Saving
