@@ -12,13 +12,13 @@ $lang['smartyvar'] = 'Smarty-Variable';
 $lang['textfield'] = 'Textfeld';
 $lang['pulldown'] = 'Aufklappliste';
 $lang['checkbox'] = 'Kontrollkästchen';
-$lang['ip_check'] = 'IP-Prüfung';
 $lang['radiobuttons'] = 'Radioknopf-Gruppe';
 $lang['datepicker'] = 'Datumsauswahl';
 $lang['datetimepicker'] = 'Datums-Zeitauswahl';
 $lang['timepicker'] = 'Zeitauswahl';
 $lang['colorpicker'] = 'Farbauswahl';
 $lang['textarea'] = 'Textbereich';
+$lang['pageselect'] = 'Seitenwähler';
 $lang['wysiwyg'] = 'Wysiwyg';
 $lang['fieldsetstart'] = 'Feldergruppe Anfang';
 $lang['fieldsetend'] = 'Feldergruppe Ende';
@@ -31,6 +31,10 @@ $lang['clearstylesheetcache'] = 'Zwischengespeicherten Stylesheets löschen';
 $lang['clearstylesheetcache_help'] = 'Automatisch zwischengespeicherten Stylesheets löschen nach Änderung dieser Einstellung. VORSICHT BEI DER VERWENDUNG!';
 $lang['fielddefadded'] = 'Die Feld-Definition wurde hinzugefügt';
 $lang['fielddefsupdated'] = 'Die Liste der Feld-Definitionen wurde aktualisiert';
+$lang['withselected'] = 'Gewählte';
+$lang['movetotop'] = 'Verschieben nach Oben';
+$lang['movetobottom'] = 'Verschieben nach Unten';
+$lang['movetogroup'] = 'Verschieben nach Gruppe';
 $lang['title_custom_modulename'] = 'Benutzerdefinierte Modulname';
 $lang['help_custom_modulename'] = 'Sie können den Modulnamen hier ändern. Es wird als Titel der Modul Admin-Seiten und als Menü Text verwendet.';
 $lang['title_admin_section'] = 'Admin-Bereich';
@@ -46,5 +50,5 @@ $lang['event_help_OnSettingChange'] = '<p>Ausführen, nachdem die Änderungen de
 <li>value</li>
 <li>clearcache</li>
 </ul>';
-$lang['ga'] = 'GA1.2.767965020.1400612364';
+$lang['ga'] = 'GA1.2.259264212.1475600489';
 ?>
\ No newline at end of file
