@@ -12,7 +12,6 @@ $lang['smartyvar'] = 'Smarty variabele';
 $lang['textfield'] = 'Tekstveld';
 $lang['pulldown'] = 'Keuzemenu';
 $lang['checkbox'] = 'Vinkvakje';
-$lang['ip_check'] = 'IP Controle';
 $lang['radiobuttons'] = 'Radiobutton groep';
 $lang['datepicker'] = 'Datumkiezer';
 $lang['datetimepicker'] = 'DatumTijdkiezer';
@@ -40,11 +39,13 @@ $lang['title_custom_modulename'] = 'Eigen Modulenaam';
 $lang['help_custom_modulename'] = 'U kunt hier de Modulenaam naar eigen wens aanpassen. Het zal gebruikt worden als titel op de module beheerpagina en als menu tekst.';
 $lang['title_admin_section'] = 'Admin Sectie';
 $lang['help_admin_section'] = 'Kies de Admin Sectie (van het Admin topmenu) waar deze module moet worden getoond. <b>Opmerking</b>: Admin gebruikers met Editor rechten hebben geen toegang tot de Admin sectie!';
+$lang['xml_export'] = 'Exporteer velden en instellingen naar XML';
+$lang['xml_import'] = 'Importeer velden en instellingen van XML';
 $lang['settingssaved'] = 'Instellingen opgeslagen!';
 $lang['updatefailed'] = 'Bijwerken mislukt!';
 $lang['event_info_OnSettingChange'] = 'Een tag die wordt aangeroepen nadat een instelling is gewijzigd.';
 $lang['event_help_OnSettingChange'] = '<p>Een tag die wordt aangeroepen nadat een instelling is gewijzigd.</p>
-<h4>Parameters</h4>
+<h4>Parameters</h4> 
 <ul>
 <li>fieldid</li>
 <li>name</li>
