@@ -1,12 +1,15 @@
 <?php
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # Module: Custom Global Settings
-# Author: Rolf Tjassens, Jos
-#-------------------------------------------------------------------------
-# CMS - CMS Made Simple is (c) 2011 by Ted Kulp (wishy@cmsmadesimple.org)
-# This project's homepage is: http://www.cmsmadesimple.org
+# Author: Rolf Tjassens (cmscanbesimple.org), Jos
+#---------------------------------------------------------------------------
+# CMS Made Simple - Power for the professional, Simplicity for the end user.
+# (c) 2004 - 2011 by Ted Kulp (wishy@cmsmadesimple.org)
+# (c) 2011 - 2018 by The CMS Made Simple Development Team
+# (c) 2018 and beyond by The CMS Made Simple Foundation
+# This project's homepage is: https://www.cmsmadesimple.org
 # The module's homepage is: http://dev.cmsmadesimple.org/projects/customgs
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -20,9 +23,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
-if (!isset($gCms)) exit;
+if ( !cmsms() ) exit;
 
 /** 
  * Install module
@@ -74,7 +77,7 @@ $sqlarray = $dict->CreateIndexSQL(cms_db_prefix()."module_customgs_tabfield", cm
 $dict->ExecuteSQLArray($sqlarray);
 
 $query = "INSERT INTO " . cms_db_prefix() . "module_customgs (name, help, type, sortorder, value) VALUES (?,?,?,?,?)";
-$db->Execute($query, array('Sample textfield', 'Sample help text for this textfield', 'textfield', 1, 'Sample value'));
+$db->Execute($query, array('Sample textfield', "Sample help text for this textfield\n<i><u>HTML</u> is allowed</i>", 'textfield', 1, 'Sample value'));
 
 $query = "INSERT INTO " . cms_db_prefix() . "module_customgs_tab (name, sortorder) VALUES (?,?)";
 $db->Execute($query, array($this->Lang("title_general"), 1));
@@ -84,4 +87,8 @@ $db->Execute($query, array(1, 1));
 
 // register an event that CustomGS will issue.
 $this->CreateEvent('OnSettingChange');
+
+#
+# EOF
+#
 ?>
\ No newline at end of file
