@@ -1,12 +1,15 @@
 <?php
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # Module: Custom Global Settings
-# Author: Rolf Tjassens, Jos
-#-------------------------------------------------------------------------
-# CMS - CMS Made Simple is (c) 2011 by Ted Kulp (wishy@cmsmadesimple.org)
-# This project's homepage is: http://www.cmsmadesimple.org
+# Author: Rolf Tjassens (cmscanbesimple.org), Jos
+#---------------------------------------------------------------------------
+# CMS Made Simple - Power for the professional, Simplicity for the end user.
+# (c) 2004 - 2011 by Ted Kulp (wishy@cmsmadesimple.org)
+# (c) 2011 - 2018 by The CMS Made Simple Development Team
+# (c) 2018 and beyond by The CMS Made Simple Foundation
+# This project's homepage is: https://www.cmsmadesimple.org
 # The module's homepage is: http://dev.cmsmadesimple.org/projects/customgs
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -20,9 +23,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 # Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
-#-------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
-if (!isset($gCms)) exit;
+if ( !cmsms() ) exit;
 
 $db = $this->GetDb();
 $taboptarray = array('mysql' => 'ENGINE=MyISAM');
@@ -145,7 +148,31 @@ switch($oldversion)
 					SELECT 1 AS tabid, fieldid FROM " . cms_db_prefix() . "module_customgs";
 		$db->Execute($query);
 
-		// current version: 3.0
+	case "3.0":
+	case "3.1":
+		$query = "UPDATE " . cms_db_prefix() . "module_customgs SET name=CONCAT(name,'.') WHERE type='fieldsetend' AND RIGHT(name,1) <> '.'";
+		$db->Execute($query);
+		$query = "DELETE tf FROM " . cms_db_prefix() . "module_customgs_tabfield tf LEFT JOIN " . cms_db_prefix() . "module_customgs f ON tf.fieldid=f.fieldid WHERE f.fieldid IS NULL";
+		$db->Execute($query);
 
-}
-?>
\ No newline at end of file
+	case "3.2":
+		// delete redundant file
+		@unlink( cms_join_path( dirname(__FILE__), 'lib', 'jquery', 'jquery-ui.smoothness.css' ) );
+
+	case "3.3":
+		// delete redundant files
+		$deletefiles = array(
+			dirname(__FILE__) . DIRECTORY_SEPARATOR . 'changelog.inc',
+			dirname(__FILE__) . DIRECTORY_SEPARATOR . 'help_text.inc'
+		);
+		foreach ($deletefiles as $deletefile) @unlink($deletefile);
+    
+		// current version: 3.4
+
+} // end switch
+
+
+
+#
+# EOF
+#
\ No newline at end of file
